@@ -12,7 +12,16 @@ class AlertPreferenceForm(forms.Form):
     backend.
     """
     
-    def __init__(self, user, alerts=None, backends=None, *args, **kwargs):        
+    def __init__(self, *args, **kwargs):
+        kwargs = kwargs.copy()
+        alerts = kwargs.pop('alerts', None)
+        backends = kwargs.pop('backends', None)
+        
+        if 'user' not in kwargs.keys():
+            raise TypeError("The \"user\" keyword argument is required but no keyword argument \"user\" was passed")
+        
+        user = kwargs.pop('user')
+                
         self.user = user
         self.alerts = super_accepter(alerts, ALERT_TYPES)
         self.backends = super_accepter(backends, ALERT_BACKENDS)
@@ -70,8 +79,8 @@ class UnsubscribeForm(AlertPreferenceForm):
     notifications. (the alert that is passed in)
     """
     
-    def __init__(self, user, *args, **kwargs):
-        super(UnsubscribeForm, self).__init__(user, *args, **kwargs)
+    def __init__(self, *args, **kwargs):
+        super(UnsubscribeForm, self).__init__(*args, **kwargs)
         
         for backend in self.backends:
             for alert in self.alerts:
